@@ -2,6 +2,8 @@
 
 import string
 
+from typing import cast, Union
+
 from public import public
 
 
@@ -23,9 +25,9 @@ class attrdict(dict):                               # type: ignore
 
     def __getitem__(self, key: str) -> str:
         parts = key.split('.')
-        value: str = super().__getitem__(parts.pop(0))
+        value: Union[str, object] = super().__getitem__(parts.pop(0))
         while parts:
             value = getattr(value, parts.pop(0), _missing)
             if value is _missing:
                 raise KeyError(key)
-        return value
+        return cast(str, value)
